=======
History
=======

0.1.0 (2020-05-27)
------------------

* First release on PyPI.
* Working pipeline execution with caching and reuse of results

0.2.0 (2020-07-01)
------------------

* Selector functionality implemented

0.2.1 (2020-07-10)
------------------

* Write intermediate pipeline results to a temp file and catch the case
  where a non-serializable object is returned

0.2.2 (2020-07-10)
------------------

* Append running dir to sys.path

0.2.3 (2020-07-10)
------------------

* Initialize artifact date_created by default
